@@ -557,3 +557,16 @@ def test_dav1d_decoder():
         Image.open("images/heif/RGB_8__128x128.avif").load()
     finally:
         pillow_heif.options.PREFERRED_DECODER["AVIF"] = ""
+
+
+@pytest.mark.skipif(
+    parse_version(pillow_heif.libheif_version()) < parse_version("1.19.7"), reason="Requires libheif 1.19.7."
+)
+def test_200_megapixels():
+    with pytest.raises(RuntimeError):
+        _ = pillow_heif.open_heif("images/heif_special/200MP.heic").data
+    try:
+        pillow_heif.options.DISABLE_SECURITY_LIMITS = True
+        _ = pillow_heif.open_heif("images/heif_special/200MP.heic").data
+    finally:
+        pillow_heif.options.DISABLE_SECURITY_LIMITS = False
